OneSidedRangeBound

Enum OneSidedRangeBound 

pub enum OneSidedRangeBound {
    StartInclusive,
    End,
    EndInclusive,
}
🔬This is a nightly-only experimental API. (one_sided_range #69780)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
An internal helper for split_off functions indicating which end a OneSidedRange is bounded on.

Variants



StartInclusive

🔬This is a nightly-only experimental API. (one_sided_range #69780)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).

The range is bounded inclusively from below and is unbounded above.



End

🔬This is a nightly-only experimental API. (one_sided_range #69780)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).

The range is bounded exclusively from above and is unbounded below.



EndInclusive

🔬This is a nightly-only experimental API. (one_sided_range #69780)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).

The range is bounded inclusively from above and is unbounded below.